==> haskell-src-exts-1.20.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts
version: 1.20.3
id: haskell-src-exts-1.20.3-GsuCuxttBof3SCq0DBKauQ
key: haskell-src-exts-1.20.3-GsuCuxttBof3SCq0DBKauQ
license: BSD-3-Clause
maintainer: Matthew Pickering <matthewtpickering@gmail.com>
author: Niklas Broberg
stability: Stable
homepage: https://github.com/haskell-suite/haskell-src-exts
synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
description:
    Haskell-Source with Extensions (HSE, haskell-src-exts)
    is a standalone parser for Haskell. In addition to
    standard Haskell, all extensions implemented in GHC are supported.
    .
    Apart from these standard extensions,
    it also handles regular patterns as per the HaRP extension
    as well as HSX-style embedded XML syntax.
category: Language
abi: 9f8a2ed3f94631eb63fe58643f1ba972
exposed: True
exposed-modules:
    Language.Haskell.Exts Language.Haskell.Exts.Build
    Language.Haskell.Exts.Comments Language.Haskell.Exts.ExactPrint
    Language.Haskell.Exts.Extension Language.Haskell.Exts.Fixity
    Language.Haskell.Exts.Lexer Language.Haskell.Exts.Parser
    Language.Haskell.Exts.Pretty Language.Haskell.Exts.SrcLoc
    Language.Haskell.Exts.Syntax
hidden-modules: Language.Haskell.Exts.ExtScheme
                Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                Language.Haskell.Exts.InternalLexer
                Language.Haskell.Exts.ParseUtils
                Language.Haskell.Exts.InternalParser Language.Preprocessor.Unlit
import-dirs: /usr/lib/ghc-8.6.3/site-local/haskell-src-exts-1.20.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/haskell-src-exts-1.20.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/haskell-src-exts-1.20.3
hs-libraries: HShaskell-src-exts-1.20.3-GsuCuxttBof3SCq0DBKauQ
depends:
    array-0.5.3.0 base-4.12.0.0 ghc-prim-0.5.3 pretty-1.1.3.6
haddock-interfaces: /usr/share/doc/haskell-src-exts/html/haskell-src-exts.haddock
haddock-html: /usr/share/doc/haskell-src-exts/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-1.20.3-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts
version: 1.20.3
id: haskell-src-exts-1.20.3-JBNjHcnj3wL9R574akoJO6
key: haskell-src-exts-1.20.3-JBNjHcnj3wL9R574akoJO6
license: BSD-3-Clause
maintainer: Matthew Pickering <matthewtpickering@gmail.com>
author: Niklas Broberg
stability: Stable
homepage: https://github.com/haskell-suite/haskell-src-exts
synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
description:
    Haskell-Source with Extensions (HSE, haskell-src-exts)
    is a standalone parser for Haskell. In addition to
    standard Haskell, all extensions implemented in GHC are supported.
    .
    Apart from these standard extensions,
    it also handles regular patterns as per the HaRP extension
    as well as HSX-style embedded XML syntax.
category: Language
abi: 991649b99327591098556ce2f736874c
exposed: True
exposed-modules:
    Language.Haskell.Exts Language.Haskell.Exts.Build
    Language.Haskell.Exts.Comments Language.Haskell.Exts.ExactPrint
    Language.Haskell.Exts.Extension Language.Haskell.Exts.Fixity
    Language.Haskell.Exts.Lexer Language.Haskell.Exts.Parser
    Language.Haskell.Exts.Pretty Language.Haskell.Exts.SrcLoc
    Language.Haskell.Exts.Syntax
hidden-modules: Language.Haskell.Exts.ExtScheme
                Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                Language.Haskell.Exts.InternalLexer
                Language.Haskell.Exts.ParseUtils
                Language.Haskell.Exts.InternalParser Language.Preprocessor.Unlit
import-dirs: /usr/lib/ghc-8.6.3/site-local/haskell-src-exts-1.20.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/haskell-src-exts-1.20.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/haskell-src-exts-1.20.3
hs-libraries: HShaskell-src-exts-1.20.3-JBNjHcnj3wL9R574akoJO6
depends:
    array-0.5.3.0 base-4.12.0.0 ghc-prim-0.5.3 pretty-1.1.3.6
haddock-interfaces: /usr/share/doc/haskell-src-exts/html/haskell-src-exts.haddock
haddock-html: /usr/share/doc/haskell-src-exts/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
